pub fn build_router(engine: QueryEngine, config: &ServerConfig) -> RouterExpand description
Build the axum router with all routes and middleware.
pub fn build_router(engine: QueryEngine, config: &ServerConfig) -> RouterBuild the axum router with all routes and middleware.